// Licensed Materials - Property of IBM
// 5725-C94, 5725-C95, 5725-C96
// Copyright IBM Corporation 2013. All Rights Reserved.
// US Government Users Restricted Rights- Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.


dojo.provide("com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper");
dojo.require("com.ibm.bpm.QuickStart.utils.Logger");

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getBPMHome = function() {
    return getEnv("WAS_HOME")+top.PATHSEPARATOR;
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getDeName = function() {
    var deName=null;
    if(top.OSTYPE=="unix"){
        deName = getEnv("deName");
    } else {
        deName = getEnv("-deName");
    }
    // top.logError("DEName="+deName);
    if(deName.search("profileName")!=-1){
        return "";
    } else {
        return deName;
    }
};  

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getProfileName = function() {
    var profileName=null;
    if(top.OSTYPE=="unix"){
        profileName = getEnv("profileName");
    } else {
        profileName = getEnv("-profileName");
    }
    if(profileName.search("userName")!=-1){
        return "";
    } else {
        return profileName;
    }
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getUserName = function() {
    var userName=null;
    if(top.OSTYPE=="unix"){
        userName = getEnv("userName");
    } else {
        userName = getEnv("-userName");
    }
    if(userName.search("password")!=-1){
        return "";
    } else {
        return userName;
    }
};  

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getPassword = function() {
    if(top.OSTYPE=="unix"){
        return getEnv("password");
    } else {
        return getEnv("-password");
    }
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getLaunchPadContentDirectory = function(){
    return top.STARTINGDIR+"launchpad"+top.PATHSEPARATOR+"content"+top.PATHSEPARATOR;
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.runJava = function(launchpadConentDirectory,jarFileName,methodName,parameters,logFileName){
    if(launchpadConentDirectory==null || jarFileName==null || parameters==null || logFileName==null ){
        return null;
     }
     // top.logError("launchpadConentDirectory = "+launchpadConentDirectory);
     runProgram(null,command("runJava",launchpadConentDirectory,jarFileName,methodName,parameters,logFileName),FOREGROUND, HIDDEN);
     var responseText = top.readTextFile(logFileName, "ASCII");
        
     if (null == responseText) {
           // message = "E: runJavaMethod returned null while fetching Launchpad updates";
//            logger.logMessage(message);
            return null;
     }
     var response = eval("(" + responseText + ")");
     return response;
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.startDE = function(BPMHome,profileName,deName,userName,password,logFileName){
    if(BPMHome==null || profileName ==null ||deName ==null ||userName == null || password == null ||logFileName==null){
        return null;
    }

    try {
    runProgram(null,command("runStartDE",BPMHome,profileName,deName,userName,password,logFileName),FOREGROUND,VISIBLE);
    } catch (exception){
        top.logError(exception);
        return false;    
    }
    return true;
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.stopDE = function(BPMHome,profileName,deName,userName,password,logFileName){
    if(BPMHome==null || profileName ==null ||deName ==null ||userName == null || password == null ||logFileName==null){
        return null;
    }
    try {
    runProgram(null,command("runStopDE",BPMHome,profileName,deName,userName,password,logFileName),FOREGROUND,VISIBLE);
    } catch (exception){
        return false;    
    }
    return true;
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.listSubDirectories = function(directory){
     var now = new Date().getTime();
     var logFileName = com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getPersistedTempFilename("listDirectories_"+now);
     runProgram(null,command("listDirectories",directory,logFileName),FOREGROUND, HIDDEN);
     var responseText = top.readTextFile(logFileName+".json", "ASCII");
        
     if (null == responseText) {
            return null;
     }
     var response = eval("(" + responseText + ")");
     return response.folders;
};
com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.isValidDoneFile = function(file){
   // logger.logMessage("I: start of isValidDoneFile method");
    
        var exits = top.fileExists(file + ".done");
        var doneFile;
        var doneStatus;
        var valid  = false;
        if(exits){
            doneFile = top.readTextFile(file + ".done", "ASCII");
            doneStatus = dojo.fromJson(doneFile);
            
            if(doneStatus.isSuccess){
                valid = true;
                return valid;
            }
        }
    
    //logger.logMessage("I: End of isValidDoneFile method with return Value"+valid);  
        
    return valid;
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getPersistedTempDirectory = function(){
    if (top.tempDir == null || !top.tempDir) {
        var now = new Date().getTime();
        tempDir = top.getNativeFileName(getEnv("LaunchPadTemp") + "/../IBM_BPM_QuickStart_" + now);

        // Create the new temp dir
        com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.createDir(tempDir);
            
        top.tempDir = tempDir;
    }
    return top.tempDir;
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getPersistedTempFilename = function(filename) {
    return top.getNativeFileName(com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getPersistedTempDirectory() + "/" + filename);
};
com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.directoryExists = function(directory){
    return top.directoryExists(NO_DISKID,directory);
}

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.createDir = function(dirNativeName) {
    if (top.isWindows()) {
        top.createDirectory(dirNativeName);
    } else {
        top.runProgram(null, top.command("createDir", dirNativeName), FOREGROUND, HIDDEN);
    }
};

com.ibm.bpm.QuickStart.Helpers.LaunchpadHelper.getStaticLogger = function(){
    if ( top.tempLogFile == null || ! top.tempLogFile ){
        top.tempLogFile = com.ibm.bpm.QuickStart.utils.Logger("BPM_QuickStart.log");
     }
     
     return top.tempLogFile;
};